changeset 61984:2ce055c7db65

[not HAVE_X_TOOLKIT] (xmenu_show): If user cancels the menu, quit unless FOR_CLICK.
author Richard M. Stallman <rms@gnu.org>
date Sun, 01 May 2005 18:49:28 +0000
parents f58aeabf21e7
children 2afdce105d7a
files src/xmenu.c
diffstat 1 files changed, 5 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/src/xmenu.c	Sun May 01 18:48:26 2005 +0000
+++ b/src/xmenu.c	Sun May 01 18:49:28 2005 +0000
@@ -2889,6 +2889,9 @@
 	    }
 	}
     }
+  else if (!for_click)
+    /* Make "Cancel" equivalent to C-g.  */
+    Fsignal (Qquit, Qnil);
 
   return Qnil;
 }
@@ -3519,8 +3522,8 @@
       entry = Qnil;
       break;
     case XM_NO_SELECT:
-      /* Make "Cancel" equivalent to C-g unless this menu was popped up by
-         a mouse press.  */
+      /* Make "Cancel" equivalent to C-g unless FOR_CLICK (which means
+	 the menu was invoked with a mouse event as POSITION).  */
       if (! for_click)
         Fsignal (Qquit, Qnil);
       entry = Qnil;